Fix ilogb/ilogbf functions to return int

This patch will fix hipDoublePrecisionMathDevice test on ThinLTO, which uncovered that hip math_function's ilogb/ilogbf should return type int instead of double. This will match rocdl.
이 커밋은 다음에 포함됨:
Aaron En Ye Shi
2017-12-05 23:14:10 +00:00
부모 a0cec19d6e
커밋 707aaef99d
2개의 변경된 파일과 4개의 추가작업 그리고 4개의 파일을 삭제
+2 -2
파일 보기
@@ -67,7 +67,7 @@ __device__ float fminf(float x, float y);
__device__ float fmodf(float x, float y);
__device__ float frexpf(float x, int* nptr);
__device__ float hypotf(float x, float y);
__device__ float ilogbf(float x);
__device__ int ilogbf(float x);
__device__ int isfinite(float a);
__device__ unsigned isinf(float a);
__device__ unsigned isnan(float a);
@@ -153,7 +153,7 @@ __device__ double fmin(double x, double y);
__device__ double fmod(double x, double y);
__device__ double frexp(double x, int *nptr);
__device__ double hypot(double x, double y);
__device__ double ilogb(double x);
__device__ int ilogb(double x);
__device__ int isfinite(double x);
__device__ unsigned isinf(double x);
__device__ unsigned isnan(double x);